local languages = {}
local currentLanguage

do
    local files = love.filesystem.getDirectoryItems('lang/')
    for _, v in ipairs(files) do
        v = string.sub(v, 1, -5)
        languages[v] = require('lang/' .. v)
    end
end

local function setLanguage(l)
    if l then
        assert(languages[l], string.format('No such language: "%s"', l))
    end
    currentLanguage = l
end

local function getLanguages()
    local langs = {}
    
    for k, _ in pairs(languages) do
        table.insert(langs, k)
    end
    
    return langs
end

local function tr(_, str)
    return currentLanguage and languages[currentLanguage][str] or str
end

return setmetatable({
    setLanguage = setLanguage,
    getLanguages = getLanguages
}, {__call = tr})
